@@ -85,46 +85,64 @@ def calc_bilinear_para(float_i, float_j, nx=None, ny=None):
 
 
 class GridTransformer(object):
-    def __init__(self, grid1, grid2):
+    def __init__(self, grid1, grid2, method='bilinear'):
         self.grid1 = grid1
         self.grid2 = grid2
+        self.method = method
         self.matrix = self.gen_matrix()
 
     def gen_matrix(self):
         I, J = self.grid1.x2i(self.grid2.X.flatten(), self.grid2.Y.flatten(), int_index=False)
-        I1 = np.floor(I).astype('i4')
-        I2 = I1 + 1
-        J1 = np.floor(J).astype('i4')
-        J2 = J1 + 1
-        X = I % 1.0
-        Y = J % 1.0
+        n_col = self.grid1.nx * self.grid1.ny
+        n_row = self.grid2.nx * self.grid2.ny
 
-        ROW_IND1 = ROW_IND2 = ROW_IND3 = ROW_IND4 = np.arange(self.grid2.nx*self.grid2.ny, dtype='i4')
-        WHERE_OUT = (I1 < 0) | (I2 >= self.grid1.nx) | (J1 < 0) | (J2 >= self.grid1.ny)
+        if self.method == 'bilinear':
+            I1 = np.floor(I).astype('i4')
+            I2 = I1 + 1
+            J1 = np.floor(J).astype('i4')
+            J2 = J1 + 1
+            X = I % 1.0
+            Y = J % 1.0
 
-        COL_IND1 = J1 * self.grid1.nx + I1
-        COL_IND2 = J1 * self.grid1.nx + I2
-        COL_IND3 = J2 * self.grid1.nx + I1
-        COL_IND4 = J2 * self.grid1.nx + I2
-        COL_IND1[WHERE_OUT] = 0
-        COL_IND2[WHERE_OUT] = 0
-        COL_IND3[WHERE_OUT] = 0
-        COL_IND4[WHERE_OUT] = 0
+            ROW_IND1 = ROW_IND2 = ROW_IND3 = ROW_IND4 = np.arange(n_row, dtype='i4')
+            WHERE_OUT = (I1 < 0) | (I2 >= self.grid1.nx) | (J1 < 0) | (J2 >= self.grid1.ny)
 
-        DATA1 = (1.0 - X) * (1.0 - Y)
-        DATA2 = X * (1.0 - Y)
-        DATA3 = (1.0 - X) * Y
-        DATA4 = X * Y
-        DATA1[WHERE_OUT] = np.nan
-        DATA2[WHERE_OUT] = np.nan
-        DATA3[WHERE_OUT] = np.nan
-        DATA4[WHERE_OUT] = np.nan
+            COL_IND1 = J1 * self.grid1.nx + I1
+            COL_IND2 = J1 * self.grid1.nx + I2
+            COL_IND3 = J2 * self.grid1.nx + I1
+            COL_IND4 = J2 * self.grid1.nx + I2
+            COL_IND1[WHERE_OUT] = 0
+            COL_IND2[WHERE_OUT] = 0
+            COL_IND3[WHERE_OUT] = 0
+            COL_IND4[WHERE_OUT] = 0
 
-        ROW_IND = np.concatenate((ROW_IND1, ROW_IND2, ROW_IND3, ROW_IND4))
-        COL_IND = np.concatenate((COL_IND1, COL_IND2, COL_IND3, COL_IND4))
-        DATA = np.concatenate((DATA1, DATA2, DATA3, DATA4))
+            DATA1 = (1.0 - X) * (1.0 - Y)
+            DATA2 = X * (1.0 - Y)
+            DATA3 = (1.0 - X) * Y
+            DATA4 = X * Y
+            DATA1[WHERE_OUT] = np.nan
+            DATA2[WHERE_OUT] = np.nan
+            DATA3[WHERE_OUT] = np.nan
+            DATA4[WHERE_OUT] = np.nan
 
-        matrix = csr_matrix((DATA, (ROW_IND, COL_IND)), shape=(len(I), self.grid1.nx*self.grid1.ny))
+            ROW_IND = np.concatenate((ROW_IND1, ROW_IND2, ROW_IND3, ROW_IND4))
+            COL_IND = np.concatenate((COL_IND1, COL_IND2, COL_IND3, COL_IND4))
+            DATA = np.concatenate((DATA1, DATA2, DATA3, DATA4))
+        elif self.method == 'nearest':
+            I1 = np.round(I).astype('i4')
+            J1 = np.round(J).astype('i4')
+
+            ROW_IND = np.arange(n_row, dtype='i4')
+            COL_IND = J1 * self.grid1.nx + I1
+            DATA = np.ones(n_row, dtype='f4')
+
+            WHERE_OUT = (I1 < 0) | (I1 > self.grid1.nx) | (J1 < 0) | (J1 > self.grid1.ny)
+            COL_IND[WHERE_OUT] = 0
+            DATA[WHERE_OUT] = np.nan
+        else:
+            raise NotImplementedError("Grid interp method: {}".format(self.method))
+
+        matrix = csr_matrix((DATA, (ROW_IND, COL_IND)), shape=(n_row, n_col))
         return matrix
 
     def __call__(self, data):
@@ -132,6 +150,6 @@ class GridTransformer(object):
         return self.matrix.dot(data.flatten()).reshape((self.grid2.ny, self.grid2.nx))
 
 
-def transform_grid(grid1, grid2, data):
-    transformer = GridTransformer(grid1, grid2)
+def transform_grid(grid1, grid2, data, method='bilinear'):
+    transformer = GridTransformer(grid1, grid2, method=method)
     return transformer(data)
\ No newline at end of file
